# -*- coding: utf-8 -*-
from setuphelpers import *
import win32com.client

r"""
Usable WAPT package functions: install(), uninstall(), session_setup(), audit(), update_package()

"""
# Declaring global variables - Warnings: 1) WAPT context is only available in package functions; 2) Global variables are not persistent between calls
printer_ip = "192.168.123.4"
printer_name = "Copieur Compta"

driver_contains = "upd-pcl6-"
driver_file = "hpcu255u.inf"
driver_name = "HP Universal Printing PCL 6"


def install():
    # Declaring local variables
    if iswin64():
        arch = "x64"
    else:
        arch = "x32"

    # Unzip drivers
    for zip_file in glob.glob("*%s*%s*.zip" % (driver_contains, arch)):
        print("Unzip drivers: %s" % zip_file)
        unzip(zip_file, ".")
        driver_dir = zip_file.rsplit(".", 1)[0]
        driver_path = glob.glob("%s/**/%s" % (driver_dir, driver_file))[0]

    # Delete old printer
    remove_printer(printer_name)

    # Create port lpr or raw
    createprinterport_raw(printer_ip)

    # use create lpr if needed
    # createprinterport_lpr(printer_ip,'qu')

    # Install printer and drivers
    print("Installing Printer: %s (%s)" % (printer_name, printer_ip))
    run(r'rundll32 printui.dll,PrintUIEntry /if /b "%s" /f %s /r  "IP_%s" /m "%s" ' % (printer_name, driver_path, printer_ip, driver_name))


def uninstall():
    remove_printer(printer_name)


def createprinterport_raw(IPAddress):
    WBEM = win32com.client.GetObject(r"winmgmts:{impersonationLevel=impersonate}!\\.\root\cimv2")
    WBEM.Security_.Privileges.AddAsString("SeLoadDriverPrivilege")
    printerport = WBEM.Get("Win32_TCPIPPrinterPort").SpawnInstance_()
    printerport.Properties_("Name").Value = "IP_" + IPAddress
    printerport.Properties_("Protocol").Value = 1
    printerport.Properties_("HostAddress").Value = IPAddress
    printerport.Properties_("PortNumber").Value = "9100"
    printerport.Properties_("SNMPEnabled").Value = "False"
    printerport.Put_()


def createprinterport_lpr(IPAddress, namequeu):
    WBEM = win32com.client.GetObject(r"winmgmts:{impersonationLevel=impersonate}!\\.\root\cimv2")
    WBEM.Security_.Privileges.AddAsString("SeLoadDriverPrivilege")
    printerport = WBEM.Get("Win32_TCPIPPrinterPort").SpawnInstance_()
    printerport.Properties_("Name").Value = "IP_" + IPAddress
    printerport.Properties_("Protocol").Value = 2
    printerport.Properties_("HostAddress").Value = IPAddress
    printerport.Properties_("SNMPEnabled").Value = "False"
    printerport.Properties_("Queue").Value = namequeu
    printerport.Put_()
